@@ -8,7 +8,7 @@ from uuid import UUID
 from grpc import RpcError
 
 from preseem import NetworkMetadataReference
-from preseem.source_model import Attachment, Olt, Router, Service
+from preseem.source_model import Olt, Router, Service
 from preseem_protobuf.model.service_pb2 import SetAttachmentReq
 
 # STM-6039 Only allow the sync to run once at a time, to prevent duplicate
@@ -187,6 +187,7 @@ async def sync_preseem_model(preseem_model,
                              accounts=None,
                              services=None,
                              routers=None,
+                             olts=None,
                              nm_model=None,
                              noact=False,
                              verbose=0):
@@ -467,7 +468,7 @@ async def sync_preseem_model(preseem_model,
                                 _service_field_map,
                                 noact=noact)
 
-        for bss_objs, source_type in (routers, Router), :
+        for bss_objs, source_type in (routers, Router), (olts, Olt):
             if bss_objs is not None:
                 assert isinstance(bss_objs, dict)
                 new_sites = set()
